function [  ] = SampledMeasurements_ICT( inputAddress )

%
% This example uses Instrument Control Toolbox to control an Agilent 34401 Digital Multimeter.
%
% Description:
% Configures the 34401 digital multimeter to take 10 DCV measurements on 
% the 10V range.   The measurements are started by a software BUS trigger. 
% Each sample measurement is delayed by 1 second.  
%
% The example demonstrates the use of Command Expert's  MATLAB export code
% feature. The following code, minus the plotting logic, was generated from
% Command Expert. 
% 
% Running the Example:
%   1. In MATLAB, change the current folder directory to the location 
%   of this SampledMeasurements.m file.  
%   2. In the MATLAB Command Window, call the function SampledMeasurements
%   with a valid GPIB or RS-232 instrument address.  An example includes:
%
%   SampledMeasurements_ICT('GPIB::22::INSTR');
%   
%
% Restrictions and Requirements:
%  1. Reset the multimeter and clear all registers.
%  2. Configure the instrument to measure DCV on the 10 V range.
%  3. Wait for measurements to complete.
%  4. Return the readings from memory.
%
% You have a royalty-free right to use, modify, reproduce and distribute
% this example program (and/or any modified version) in any way you find
% useful, provided you agree that Agilent Technologies has no warranty,
% obligations, or liability for any example programs.
%


v34401a = visa('agilent', inputAddress);
v34401a.InputBufferSize = 8388608;
v34401a.ByteOrder = 'littleEndian';
fopen(v34401a);

fprintf(v34401a, '*RST');
fprintf(v34401a, '*CLS');
fprintf(v34401a, sprintf(':CONFigure:VOLTage:DC %f,%f', 10.0, 10.0));
fprintf(v34401a, sprintf(':SAMPle:COUNt %d', 10));
fprintf(v34401a, sprintf(':TRIGger:DELay %f', 1.0));
fprintf(v34401a, sprintf(':TRIGger:SOURce %s', 'BUS'));

fprintf('Please wait 10 seconds for voltage measurements to complete');

fprintf(v34401a, ':INITiate');
fprintf(v34401a, '*TRG');
C = textscan(query(v34401a, ':FETCh?'), '%f', 'Delimiter', ',');
readings = C{1};

fclose(v34401a);
delete(v34401a);
clear v34401a;

%Example captures 10 samples
x = 1:1:10;
% Plot measurement data.
plot(x, readings);
title('Sampled Measurements');
xlabel('Voltage Sample Number');
ylabel('Voltage (V)');

end

