%
% Description:
% Configures the 34401 digital multimeter to take 10 DCV measurements on 
% the 10V range.   The measurements are started by a software BUS trigger. 
% Each sample measurement is delayed by 1 second.   
%
% The example demonstrates using the agRunSequence
% function to run the Command Expert sequence file
% 34401_DigitalMultimeter_SampledMeasurements.iseq that is included in 
% the same directory as this file.
% 
% Running the Example:
%   1. In the MATLAB Command Window, assign the variable named 'address' a
%   string value that is the instrument address of an Agilent 34401 Digital
%   Multimeter. For example, you would type the following, replacing
%   'abcdefg' with your instrument address.
%
%   address = 'abcdefg';
%
%   A commom GPIB instrument address is GPIB0::22::INSTR.
%   See the help for agRunSequence for additional instrument address details.
%
%   2. With this file open in the MATLAB editor, click the Run button.
%
% Restrictions and Requirements:
%  1. Reset the multimeter and clear all registers.
%  2. Configure the instrument to measure DCV on the 10 V range.
%  3. Wait for measurements to complete.
%  4. Return the readings from memory.
%
% You have a royalty-free right to use, modify, reproduce and distribute
% this example program (and/or any modified version) in any way you find
% useful, provided you agree that Agilent Technologies has no warranty,
% obligations, or liability for any example programs.
%
% See also agRunSequence.


fprintf('Please wait 10 seconds for voltage measurements to complete');

% Run the Command Expert sequence.
[voltageSamples] = agRunSequence('34401_DigitalMultimeter_SampledMeasurements', address);


%Example captures 10 samples
x = 1:1:10;
% Plot measurement data.
plot(x, voltageSamples);
title('Sampled Measurements');
xlabel('Voltage Sample Number');
ylabel('Voltage (V)');

