% This example demonstrates using the agRunSequence
% function to run the Command Expert sequence file
% 3497x_DataAcquisition_ThermocoupleAndVoltageMeasurements.iseq that is included in 
% the same directory as this file.
%
% Description:
% Configure the 3497x Data Acquisition unit to gather temperature and DC voltage measurements. 
% The acquisition is started by a software trigger.  This example measures channels 1-10 for type J 
% thermocouple temperatures in Celcius and channels 11-20 for DC voltage.  
%
% Running the Example:
%   1. In the MATLAB Command Window, assign the variable named 'address' a
%   string value that is the instrument address of an Agilent 3497x Data Acquisition
%   Unit.  
%   For example, you would type the following, replacing
%   'abcdefg' with your instrument address.
%
%   address = 'abcdefg';
%
%   A commom GPIB instrument address is GPIB::6::INSTR.
%   See the help for agRunSequence for additional instrument address details.
%   
%   2. This example requires that the instrument has a multiplexer card
%   installed (see below for details).  
%
%   3. With this file open in the MATLAB editor, click the Run button.
%
%Instructions for setting up the Multiplexer Card
%    1.  This example uses a 20 channel multiplexer card (model 34901A).
%    2.  Channels 1-10 are reserved for using type J thermocouple measurements, while Channels 11-20 
%        are used for DC voltage measurements.
%    3.  This example requires the card be placed into first slot. 
%
% You have a royalty-free right to use, modify, reproduce and distribute
% this example program (and/or any modified version) in any way you find
% useful, provided you agree that Agilent Technologies has no warranty,
% obligations, or liability for any example programs.
%
% See also agRunSequence().

fprintf('Please wait up to 10 seconds for 3497x to complete a measurement scan cycle. \n');

% Run the Command Expert sequence.
[thermo,voltage] = agRunSequence('3497x_DataAcquisition_ThermocoupleAndVoltageMeasurements', address);

% Convert and print out thermo and voltage values
fprintf(1,'Thermo Readings (C) from Channels 1-10:\n');
t = strread(thermo,'%s','delimiter',',')

fprintf(1,'Voltage Readings (V) from Channels 11-20:\n');
v = strread(voltage,'%s','delimiter',',')






