% This example demonstrates using the agRunSequence
% function to run the Command Expert sequence file
% 532xx_FrequencyCounter_MultisetMeasurement.iseq that is included in 
% the same directory as this file.
%
% Description:
% Configures the 532xx frequency counter to measure 10 frequency samples 
% on channel 1. The measurement is started by an external trigger.  The 
% counter detects an external trigger, delays one second, takes 5 frequency 
% measurements, receives a second external trigger, delays one second, 
% and then completes the remaining 5 measurements.      
%
% Running the Example:
%   1. In the MATLAB Command Window, assign the variable named 'address' a
%   string value that is the address of an Agilent 532XX Frequency Counter. 
%
%   For example, you would type the following, replacing
%   'abcdefg' with your instrument address.
%
%   address = 'abcdefg';
%
%   A commom GPIB instrument address is GPIB0::12::INSTR.
%   See the help for agRunSequence for additional instrument address details.
%   
%   2. Place an appropriate AC input source into the selected channel variable "channelSource". 
%   The symbol "@1" refers to the first channel and "@2" refers to the second channel.
%   
%   3. Add another TTL level source into the rear EXT channel that will trigger the measurement.
%    
%   4. Change the expected frequency, gatetime, and/or trigger delay to match your source.    
%
%   5. With this file open in the MATLAB editor, click the Run button.
%
% Requirements
% This example was written for an Agilent 532xx frequency counter.  It was tested on firmware version 1.10. 
%
% You have a royalty-free right to use, modify, reproduce and distribute
% this example program (and/or any modified version) in any way you find
% useful, provided you agree that Agilent Technologies has no warranty,
% obligations, or liability for any example programs.
%
% See also agRunSequence.

fprintf('Please wait a few seconds for the 532XX to complete the measurement cycle. \n');

%Change these values for your measurement setup
expectedFrequency = '1000'; %By default, expect a 1000 hertz signal
gateTime = '.001';   %Gate Time expected to be .001 seconds
channelSource = '@1';
triggerDelay = 1; %trigger delay is one second

% Run the Command Expert sequence.
[frequencyData] = agRunSequence('532xx_FrequencyCounter_MultisetMeasurement', address,expectedFrequency,gateTime,channelSource,triggerDelay);

%Plot Frequency Values
plot(1:1:10,frequencyData);
title('Frequency Capture Plot');
ylabel('Frequency (Hz)');
xlabel('Sample Point');








