% Description:
% Acquires an autoscaled waveform from a selectable channel of an Agilent InfiniiVision 
% 3000 Series oscilloscope.  
%
% The example demonstrates using the agRunSequence
% function to run the Command Expert sequence file
% InfiniiVision_3000Series_WaveformDownload.iseq that is included in 
% the same directory as this file.
% 
% Running the Example:
%   1. In the MATLAB Command Window, assign the variable named 'address' a
%   string value that is the instrument address of an Agilent 3000 Series  
%   Oscilloscope. For example, you would type the following, replacing
%   'abcdefg' with your instrument address.
%
%   address = 'abcdefg';
%
%   A commom LAN instrument address is TCPIP0::192.XXX.XXX.XXX::inst0::INSTR.
%   See the help for agRunSequence for additional instrument address details.
%
%   2. Change the channel variable with the correct channel input source.
%   For example, change the variable CHANNEL1 to CHANNEL2 to change the
%   input source from channel 1 to 2.  
%   2. Add an appropriate input source to channel selected.
%   3. With this file open in the MATLAB editor, click the Run button.
%
% Viewing the Plot
% This sequence grabs 1000 points to represent the waveform.  It 
%captures the data in the BYTE format that is translated using the y-axis
%preamble information. Time data (x-axis) can be generated by using the preamble's
%x-origin and x-increment information.  
%
% Restrictions and Requirements:
% This example was written for oscilloscopes in the Agilent Infiniium  
%3000 Series. This was tested with firmware version 01.10.20111042700.
%
% You have a royalty-free right to use, modify, reproduce and distribute
% this example program (and/or any modified version) in any way you find
% useful, provided you agree that Agilent Technologies has no warranty,
% obligations, or liability for any example programs.
%
% See also agRunSequence.
fprintf('Please wait up to 10 seconds for scope to return waveform data.\n');

%Define Channel Number
channel = 'CHANNEL1'; 

% Run the Command Expert sequence.
[xincrement,xorigin,yincrement,yorigin,yreference,waveformBYTEData] = agRunSequence('InfiniiVision_3000Series_WaveformDownload',address,channel);


waveformBYTEData = double(waveformBYTEData);
yAxisVoltage = size(1, max(size(waveformBYTEData)));
yAxisVoltage = double(yAxisVoltage);

%Generate Y-Axis Time Values
i = 1;
while(i <= max(size(waveformBYTEData)))
    yAxisVoltage(i) = waveformBYTEData(i) - yreference;
    yAxisVoltage(i) = yAxisVoltage(i)*yincrement+yorigin; 
    i = i + 1;   
end

%Generate X-Axis Time Values
xAxisTime(1) = xorigin;
i = 2;
while(i <= max(size(waveformBYTEData)))
    xAxisTime(i) = xAxisTime(i-1) + xincrement;        %#ok<SAGROW>
    i = i + 1;
end

plot(xAxisTime, yAxisVoltage)
title('Waveform Download');
xlabel('Time(s)');
ylabel('Voltage (V)');



