﻿/* 
 * This example uses the .NET Run Sequence functionality in Command Expert.
 *
 * Description:
 * Configures the 34401 digital multimeter to take 10 DCV measurements on the 10V range.   
 * The measurements are started by a software BUS trigger.  Each sample measurement is delayed by 1 second.   
 *
 * Instructions for Running:
 * 1. Setup the multimeter for a DC voltage measurement.
 * 2. Enter your instrument address in the instrument declaration ("Fill in Address") below.
 * 3. Copy the 34401_DigitalMultimeter_SampledMeasurements.iseq file into the program's run directory.
 * 4. Run the sequence.
 *
 * Instructions for compiling.
 *   This example requires that Command Expert be installed along with the Agilent 34401 command set.
 *   The Run Sequence library locations can be found in the Command Expert's help file under "File Locations".
 *
 * Requirements:
 * This example was written for an Agilent 34401A digital multimeter. 
 *
 * You have a royalty-free right to use, modify, reproduce and distribute 
 * this example program (and/or any modified version) in any way you find useful,
 * provided you agree that Agilent Technologies has no warranty, obligations, or liability for any example programs.
 */

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Agilent.CommandExpert.DataModel.Sequence;
using Agilent.CommandExpert.SequenceExecution;

namespace SampledMeasurementsRunSequence
{
    class Program
    {
        static void Main(string[] args)
        {
            SequenceModel seq = new SequenceModel();
            seq.Load("34401_DigitalMultimeter_SampledMeasurements.iseq");
            seq.SetInstrumentAddresses("Fill in instrument's address");

            Console.WriteLine("Wait 10 seconds for the voltage measurements to complete.\n");
            object[] ret = seq.Play();
            double[] voltageReadings = (double[])(ret[0]);

            for (int i = 0; i < voltageReadings.Length; i++)
            {
                Console.WriteLine("\tVoltage Sample " + (i + 1) + ": Reads " + voltageReadings[i] + " (V)\n");
            }

            //Hang Console
            Console.WriteLine("Hit enter key to exit\n");
            Console.ReadLine();

        }
    }
}
