﻿' 
' This example uses the .NET Run Sequence functionality in Command Expert.
'
' Description:
' Configures the 34401 digital multimeter to take 10 DCV measurements on the 10V range.   
' The measurements are started by a software BUS trigger.  Each sample measurement is delayed by 1 second.   
'
' Instructions for Running:
' 1. Setup the multimeter for a DC voltage measurement.
' 2. Enter your instrument address in the instrument declaration ("Fill in Address") below.
' 3. Copy the 34401_DigitalMultimeter_SampledMeasurements.iseq file into the program's run directory.
' 4. Run the sequence.
'
' Instructions for compiling.
'   This example requires that Command Expert be installed along with the Agilent 34401 command set.
'   The Run Sequence library locations can be found in the Command Expert's help file under "File Locations".
'
' Requirements:
' This example was written for an Agilent 34401A digital multimeter. 
'
' You have a royalty-free right to use, modify, reproduce and distribute 
' this example program (and/or any modified version) in any way you find useful,
' provided you agree that Agilent Technologies has no warranty, obligations, or liability for any example programs.
'
Imports Agilent.CommandExpert.DataModel.Sequence
Imports Agilent.CommandExpert.SequenceExecution

Module Module1

    Sub Main()

        Dim seq As New SequenceModel
        seq.Load("34401_DigitalMultimeter_SampledMeasurements.iseq")
        seq.SetInstrumentAddresses("Fill in instrument's address")

        Console.WriteLine("Wait 10 seconds for the voltage measurements to complete.")
        Dim ret() As Object = seq.Play()
        Dim voltageReadings() As Double = ret(0)

        'Print out voltage measurements
        Dim i = 0
        Do
            Console.WriteLine(vbTab + "Voltage Sample {0}: Reads {1} (V)" + vbNewLine, (i + 1), voltageReadings(i))
            i = i + 1
        Loop Until i = voltageReadings.Length

        'Hang Console
        Console.WriteLine("Hit enter key to exit" + vbNewLine)
        Console.ReadLine()


    End Sub

End Module
