﻿/* 
 * This example uses the SCPI.NET driver to control an Agilent 34401 Digital Multimeter.
 *
 * Description:
 * Configures the 34401 digital multimeter to take 10 DCV measurements on the 10V range.   
 * The measurements are started by a software BUS trigger.  Each sample measurement is delayed by 1 second.   
 *
 * Instructions for Running:
 * 1. Setup the multimeter for a DC voltage measurement.
 * 2. Enter your instrument address in the instrument declaration ("Fill in Address") below.
 * 3. Run the sequence.
 *
 * Instructions for compiling.
 *   This example requires that Command Expert be installed along with the Agilent 34401 command set.
 *   The SCPI.NET driver location can be found in the Command Expert's help file under "File Locations".
 *    
 *
 * Requirements:
 * This example was written for an Agilent 34401A digital multimeter. 
 *
 * You have a royalty-free right to use, modify, reproduce and distribute 
 * this example program (and/or any modified version) in any way you find useful,
 * provided you agree that Agilent Technologies has no warranty, obligations, or liability for any example programs.
 */

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Agilent.CommandExpert.ScpiNet.Ag34401_11;

namespace SampleMeasurementSCPIDOTNET
{
    class Program
    {
        static void Main(string[] args)
        {
            double[] voltageReadings = new double[10];

            Ag34401 v34401a = new Ag34401("Fill in instrument address");
            v34401a.Transport.DefaultTimeout.Set(11000);
            v34401a.SCPI.RST.Command();
            v34401a.SCPI.CLS.Command();
            v34401a.SCPI.CONFigure.VOLTage.DC.Command(10, 10);
            v34401a.SCPI.SAMPle.COUNt.Command(10);
            v34401a.SCPI.TRIGger.DELay.Command(1);
            v34401a.SCPI.TRIGger.SOURce.Command("BUS");
            v34401a.SCPI.INITiate.Command();

            Console.WriteLine("Wait 10 seconds for the voltage measurements to complete.");
            v34401a.SCPI.TRG.Command();
            v34401a.SCPI.FETCh.Query(out voltageReadings);

            for (int i = 0; i < voltageReadings.Length; i++)
            {
                Console.WriteLine("\tVoltage Sample " + (i + 1) + ": Reads " + voltageReadings[i] + " (V)\n");
            }

            //Hang Console
            Console.WriteLine("Hit enter key to exit\n");
            Console.ReadLine();
        }
    }
}