/* 
 * This example uses the VISA Library to control an Agilent 34401 Digital Multimeter.
 *
 * Description:
 * Configures the 34401 digital multimeter to take 10 DCV measurements on the 10V range.   
 * The measurements are started by a software BUS trigger.  Each sample measurement is delayed by 1 second. 
 *
 * Instructions for Running:
 * 1. Setup the multimeter for a DC voltage measurement.
 * 2. Enter your instrument address in the viOpen("Fill in Address") command below.
 * 3. Run the sequence.
 *
 * Instructions for compiling.
 *    This example calls the VISA library which is installed by Agilent IO Library Suite.     
 *    
 * Requirements:
 * This example was written for an Agilent 34401A digital multimeter. 
 *
 * You have a royalty-free right to use, modify, reproduce and distribute 
 * this example program (and/or any modified version) in any way you find useful,
 * provided you agree that Agilent Technologies has no warranty, obligations, or liability for any example programs.
 */


#include "stdafx.h"
#include "visa.h"

int _tmain(int argc, _TCHAR* argv[])
{
	ViSession rm;
	viOpenDefaultRM(&rm);
	ViSession v34401a;
	double voltageReadings[10];
	
	 
	viOpen(rm, "Fill in Address", VI_NULL, VI_NULL, &v34401a);
	viSetAttribute(v34401a,VI_ATTR_TMO_VALUE, 11000);
	viPrintf(v34401a, "*RST\n");
	viPrintf(v34401a, "*CLS\n");
	viPrintf(v34401a, ":CONFigure:VOLTage:DC %d,%d\n", 10, 10);
	viPrintf(v34401a, ":SAMPle:COUNt %d\n", 10);
	viPrintf(v34401a, ":TRIGger:DELay %d\n", 1);
	viPrintf(v34401a, ":TRIGger:SOURce %s\n", "BUS");
	viPrintf(v34401a, ":INITiate\n");

	printf("Wait 10 seconds for the voltage readings to complete\n");
	viPrintf(v34401a, "*TRG\n");
	viQueryf(v34401a, ":FETCh?\n", "%,10lf", &voltageReadings);

	//Print out Recorded Voltage Readings
	for(int i = 0; i < 10; i++)
	{
		printf("\tVoltage Sample %d: Reads %2.2f (V)\n\n",i+1,voltageReadings[i]);
	}

	viClose(v34401a);

	//Hang Console
	printf("Press enter to exit");
	getch();

	return 0;
}



