﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Agilent.CommandExpert.DataModel.Sequence;
using Agilent.CommandExpert.SequenceExecution;

/* 
 * Description
 * Configure the 3497x Data Acquisition unit to gather temperature and DC voltage measurements. 
 * The acquisition is started by a software trigger.  This example measures channels 1-10 for type J 
 * thermocouple temperatures in Celcius and channels 11-20 for DC voltage.    
 * 
 * Instructions for Running:
 *  1. Setup the multiplexer card for temperature and voltage measurements(see below). 
 *  2. Insert multiplexer card into the first slot.
 *  3. Update the instrument address in the connect statement.
 *  3. Copy the 3497x_DataAcquisition_ThermocoupleAndVoltageMeasurements.iseq into the program's run directory.
 *  4. Run the sequence.
 *  
 * Instructions for setting up the Multiplexer Card
 *  1. This example uses a 20 channel multiplexer card (model 34901A).
 *  2. Channels 1-10 are reserved for using type J thermocouple measurements, while Channels 11-20 
 *     are used for DC voltage measurements.
 *  3. This example requires the card be placed into the first slot.
 *  
 *  
 * Requirements:
 * This example was written for an Agilent 34970A or 34972A Data Acquisition Unit.  
 *
 * You have a royalty-free right to use, modify, reproduce and distribute 
 * this example program (and/or any modified version) in any way you find useful,
 * provided you agree that Agilent Technologies has no warranty, obligations, or liability for any example programs.
 */

namespace ThermocoupleandVoltageRunSequence
{
    class Program
    {
        static void Main(string[] args)
        {
            string thermoReadings;
            string voltageReadings;

            SequenceModel seq = new SequenceModel();
            seq.Load("3497x_DataAcquisition_ThermocoupleAndVoltageMeasurements.iseq");
            seq.SetInstrumentAddresses("To Be Filled");

            Console.WriteLine("Please wait 10 seconds for the measurement to complete.");
            object[] ret = seq.Play();
            thermoReadings = (string)(ret[0]);
            voltageReadings = (string)(ret[1]);

            //split comma seperated array
            string[] tArray = thermoReadings.Split(',');
            string[] vArray = voltageReadings.Split(',');

            //print out measured thermo values
            for (int i = 0; i < 10; i++)
            {
                Console.Out.WriteLine("Channel " + (i + 1) + ": " + tArray[i] + " (C)");
            }

            //print out measured voltage values
            for (int i = 0; i < 10; i++)
            {
                Console.Out.WriteLine("Channel " + (i + 11) + ": " + vArray[i] + " (V)");
            }

            //Stall Console
            Console.WriteLine("\nPress enter to continue . . .");
            Console.ReadLine();
            
        }
    }
}
