﻿Imports Agilent.CommandExpert.DataModel.Sequence
Imports Agilent.CommandExpert.SequenceExecution

'
' Description
' Configure the 3497x Data Acquisition unit to gather temperature and DC voltage measurements. 
' The acquisition is started by a software trigger.  This example measures channels 1-10 for type J 
' thermocouple temperatures in Celcius and channels 11-20 for DC voltage.    
' 
' Instructions for Running:
'  1. Setup the multiplexer card for temperature and voltage measurements(see below). 
'  2. Insert multiplexer card into the first slot.
'  3. Update the instrument address in the connect statement.
'  3. Copy the 3497x_DataAcquisition_ThermocoupleAndVoltageMeasurements.iseq into the program's run directory.
'  4. Run the sequence.
'  
'  Instructions for setting up the Multiplexer Card
'  1. This example uses a 20 channel multiplexer card (model 34901A).
'  2. Channels 1-10 are reserved for using type J thermocouple measurements, while Channels 11-20 
'     are used for DC voltage measurements.
'  3. This example requires the card be placed into the first slot.
'    
' Requirements:
' This example was written for an Agilent 34970A or 34972A Data Acquisition Unit.  
'
' You have a royalty-free right to use, modify, reproduce and distribute 
' this example program (and/or any modified version) in any way you find useful,
' provided you agree that Agilent Technologies has no warranty, obligations, or liability for any example programs.
'

Module Module1

    Sub Main()

        Dim seq As New SequenceModel
        seq.Load("3497x_DataAcquisition_ThermocoupleAndVoltageMeasurements.iseq")
        seq.SetInstrumentAddresses("To Be Filled")

        Console.WriteLine("Please wait 10 seconds for the measurement to complete.")
        Dim ret() As Object = seq.Play()
        Dim thermoReadings As String = ret(0)
        Dim voltageReadings As String = ret(1)

        'Split comma seperated strings
        Dim tArray() As String = thermoReadings.Split(",")
        Dim vArray() As String = voltageReadings.Split(",")

        'Print out Measured Values
        Dim i As Integer

        For i = 0 To 9
            Console.Out.WriteLine("Channel {0}: {1} (C)", (i + 1), tArray(i))
        Next i

        For i = 0 To 9
            Console.Out.WriteLine("Channel {0}: {1} (V)", (i + 11), vArray(i))
        Next i

        'Stall console
        Console.WriteLine("Hit enter key to exit" + vbNewLine)
        Console.ReadLine()

    End Sub

End Module
