﻿' 
'  This example uses the SCPI.NET driver to control an Agilent 532xx Frequency Counter.
' 
'  Description
'  Configures the 532xx frequency counter to measure 10 frequency samples on channel 1.  
'  The measurement is started by an external trigger.  The counter detects an external trigger, 
'  delays one second, takes 5 frequency measurements, receives a second external trigger, 
'  delays one second, and then completes the remaining 5 measurements.  
' 
' Instructions for Running:
'  1. Place an appropriate input source into selected channel and then alter the 'channelSource' variable.
'     The symbol @1 refers to channel1 while @2 refers to channel2.  
'  2. Add another source into the rear EXT channel that will trigger the measurement. 
'  3. Change the expected frequency, gatetime, and/or trigger delay to match your source.  
'  4. Update the first connect statement with a valid instrument address.  
'  5. Run this program.  
' 
'  Instructions for compiling.
'   This example calls the SCPI.NET 532xx driver that is needed as a reference.  This file is downloaded when 
'   Command Expert installs a Command Set.  See Command Expert's Visual Studio help for additional information.     
'     
'  Requirements
'   This example was written for an Agilent 532xx frequency counter.  It was tested on firmware version 1.10.   
'   The external trigger source must receive a TTL level signal and the input channel must receive an AC signal. 
' 
'  You have a royalty-free right to use, modify, reproduce and distribute 
'  this example program (and/or any modified version) in any way you find useful,
'  provided you agree that Agilent Technologies has no warranty, obligations, or liability for any example programs.
' 

Imports Agilent.CommandExpert.ScpiNet.Ag532xx_1_05

Module Module1

    Sub Main()
        Dim expectedFrequency As Double = 1000  'expected frequency is in hertz
        Dim gateTime As Double = 0.001          'gate time is in seconds
        Dim channelSource As String = "@1"      ' @1 = Channel 1, @2 = Channel 2

        Dim triggerDelay As Double = 1          'trigger delay is in seconds- long trigger delays require a longer default timeout 

        Dim numFrequencyReadings As Integer = 10 'By default this example gathers 10 frequency readings
        Dim frequencyData As Double() = Nothing

        Dim v532xx As Ag532xx = New Ag532xx("To Be Filled")

        Console.WriteLine("Please wait a few seconds for the measurements to complete")

        v532xx.Transport.DefaultTimeout.Set(5000)
        v532xx.SCPI.RST.Command()
        v532xx.SCPI.CLS.Command()
        v532xx.SCPI.CONFigure.SCALar.VOLTage.FREQuency.Command(expectedFrequency, gateTime, channelSource)
        v532xx.SCPI.TRIGger.SEQuence.SOURce.Command("EXTernal")
        v532xx.SCPI.TRIGger.SEQuence.SLOPe.Command("POSitive")
        v532xx.SCPI.TRIGger.SEQuence.COUNt.Command(2)
        v532xx.SCPI.TRIGger.DELay.Command(triggerDelay)
        v532xx.SCPI.SAMPle.COUNt.Command(5)
        v532xx.SCPI.READ.QueryAsciiReal(frequencyData)

        'Print out frequency values
        Dim i As Integer

        For i = 0 To numFrequencyReadings - 1
            Console.WriteLine("Frequency Sample {0} reads: {1} (Hz)", (i + 1), frequencyData(i))
        Next i

        'Wait for user input
        Console.WriteLine("Press enter to exit"+vbNewLine)
        Console.ReadLine()

    End Sub

End Module
