﻿'
' Description
' Performs a voltage sweep and measures the current drawn at each voltage point. This example sweeps
' the 6V Source (P6V) 0V to 3V in .5V intervals.  Each voltage level is held for 2 seconds before switching to 
' next.  
' 
' Instructions for Running:
' 1. Copy the E3631_PowerSupply_VoltageSweep.iseq run sequence file into the program's run directory.
' 2. Update the instrument address in the "To Be Filled" connect statement.
' 3. Switch the outputSource variable to the selected source.
'      P6V  - Refers to the 6V Source
'      P25V - Refers to positive 25V Source
'      N25V - Referes to negative 25V Source
' 4. Adjust the voltageList array with voltage values within the selected source's range.  For example, the P6V 
'    is limited to 6V while the N25V source accepts negative voltage values greater than or equal to -25V.  
' 5. Open the E3631_PowerSupply_VoltageSweep.iseq file and change the wait statement to increase or decrease the 
'    time each voltage point is held before switching to the next.   
' 6. For RS-232 connections only, uncomment the "SYSTem:Remote" command in the sequence file.
' 7. Run this program.
' 
' Viewing the Data
' This console application lacks a graphing component for simplicity.  Instead, each voltage point measures the current 
' drawn.  This example prints these values out.  
'    
' Requirements:
' This example was written for the Agilent E3631A Triple Output DC Power Supply, and was tested with firmware version 1.1-5.0-1.0. 
'
' You have a royalty-free right to use, modify, reproduce and distribute 
' this example program (and/or any modified version) in any way you find useful,
' provided you agree that Agilent Technologies has no warranty, obligations, or liability for any example programs.
'
Imports Agilent.CommandExpert.DataModel.Sequence
Imports Agilent.CommandExpert.SequenceExecution

Module Module1

    Sub Main()

        Dim voltageList() As Double = {0, 0.5, 1, 1.5, 2, 2.5, 3} 'Adustable power supply voltage levels
        Dim voltageInterval As Integer = 2000                     '2 Seconds for each voltage level
        Dim outputSource As String = "P6V"                        'Values can be: P6V , P25V, or N25V

        Dim outputCurrent(voltageList.Length) As Double
        Dim outputVoltage(voltageList.Length) As Double

        Dim seq As New SequenceModel
        seq.Load("E3631_PowerSupply_VoltageSweep.iseq")
        seq.SetInstrumentAddresses("To Be Filled")

        Dim ret() As Object

        For i = 0 To (voltageList.Length)

            'If we are past the last voltage point then turn off the source
            If (i = voltageList.Length) Then
                ret = seq.Play("0", outputSource, "0")
            Else
                ret = seq.Play(voltageList(i), outputSource, "1")
                outputCurrent(i) = ret(0)
                outputVoltage(i) = ret(1)
                Console.WriteLine("Voltage Level(V): {0} consumed {1} (A)", outputVoltage(i), outputCurrent(i))

                'Wait 2 seconds until the PSU outputs next voltage level
                System.Threading.Thread.Sleep(voltageInterval)
            End If

        Next i

        'Hang Console
        Console.WriteLine("Press any key to exit")
        Console.ReadLine()

    End Sub

End Module
