﻿' 
' This example uses the SCPI.NET driver to control an Agilent E3631A Power Supply.
'
' Description
' Performs a voltage sweep and measures the current drawn at each voltage point. By default this example sweeps
' the 6V Source (P6V) 0V to 3V in .5V intervals.  Each voltage level is held for 2 seconds before switching to 
' next.  
' 
' Instructions for Running:
' 1. Update the instrument address in the "To Be Filled" connect statement.
' 2. Switch the outputSource variable to the selected source.
'      P6V  - Refers to the 6V Source
'      P25V - Refers to positive 25V Source
'      N25V - Referes to negative 25V Source
' 3. Adjust the VoltageList array with voltage values within the selected source's range.  For example, the P6V 
'    is limited to 6V while the N25V source accepts negative voltage values greater than or equal to -25V.  
' 4. Adjust the voltageInterval duration variable, in milliseconds, to hold the voltage level before switching to the next point. 
' 5. For RS-232 connections only, uncomment the "SYSTem:Remote" command.
' 5. Run this program.
'
' Instructions for compiling.
' This example calls the SCPI.NET E3631A driver that is needed as a reference.  This file is downloaded when 
' Command Expert installs the Agilent E3631A command set.  See Command Expert's Visual Studio help for additional 
' information on file locations. 
' 
' Viewing the Data
' This console application lacks a graphing component for simplicity.  Instead, each voltage point measures the current 
' drawn.  This example prints these values out.  
'    
' Requirements:
' This example was written for the Agilent E3631A Triple Output DC Power Supply, and was tested with firmware version 1.1-5.0-1.0. 
'
' You have a royalty-free right to use, modify, reproduce and distribute 
' this example program (and/or any modified version) in any way you find useful,
' provided you agree that Agilent Technologies has no warranty, obligations, or liability for any example programs.
'

Imports Agilent.CommandExpert.ScpiNet.AgE3631_2_1
Module Module1

    Sub Main()
        Dim voltageList() As Double = {0, 0.5, 1, 1.5, 2, 2.5, 3} 'Adustable power supply voltage levels
        Dim voltageInterval As Integer = 2000                     '2 Seconds for each voltage level
        Dim outputSource As String = "P6V"                        'Values can be: P6V , P25V, or N25V

        Dim outputCurrent(voltageList.Length) As Double
        Dim outputVoltage(voltageList.Length) As Double

        Dim E3631a As AgE3631 = New AgE3631("To Be Filled")

        'If you are using the RS-232 interface then uncomment the next command
        'E3631.SCPI.SYSTem.REMote.Command

        'Turn on Power Supply
        E3631a.SCPI.OUTPut.STATe.Command(True)

        'Cycle thru each voltage level and measure the current drawn
        For i = 0 To (voltageList.Length - 1)
            E3631a.SCPI.APPLy.Command(outputSource, voltageList(i), DBNull.Value)

            'Wait 2 seconds until the PSU outputs next voltage level
            System.Threading.Thread.Sleep(voltageInterval)

            E3631a.SCPI.MEASure.CURRent.DC.Query("P6V", outputCurrent(i))
            E3631a.SCPI.MEASure.VOLTage.DC.Query("P6V", outputVoltage(i))
            Console.WriteLine("Voltage Level(V): {0} consumed {1} (A)", outputVoltage(i), outputCurrent(i))


            

        Next i

        'Turn off Power Supply
        E3631a.SCPI.OUTPut.STATe.Command(False)

        'Hang Console
        Console.WriteLine("Press any key to exit")
        Console.ReadLine()

    End Sub

End Module

