﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Agilent.CommandExpert.DataModel.Sequence;
using Agilent.CommandExpert.SequenceExecution;

/* 
 * Acquires an autoscaled waveform from a selectable channel of an Agilent InfiniiVision 3000 Series oscilloscope.
 *
 * Description
 * This program's uses the .NET Run Sequence functionality in Command Expert. For simplicity sake, this example 
 * merely grabs the x and y axis waveform data.  It does not graph it.  
 * 
 * Instructions for Running:
 * 1. Update the instrument's address below in the SetInstrumentAddress function. Copy the sequence file
 *    to the program's run directory.  Change the Channel number below. 
 * 2. Add an appropriate input source to the 3000 series oscilloscope.
 * 3. Copy the "InfiniiVision_3000Series_WaveformDownload.iseq" file into the program's run directory. Ex: Debug\Bin
 * 4. Run this program.
 *  
 * Viewing the Data
 * This example lacks a graphing component for the sack of simplicity. The waveform data is returned in the BYTE format to 
 * increase efficiency across the bus.  The conversion needed uses y-axis preamble information.  The x-axis uses a different
 * set of preamble information. Please see the code below for the conversion information.  
 *    
 * Requirements:
 * This example was written for oscilloscopes in the Agilent InfiniiVision 3000 Series. This was tested with firmware version 01.10.20111042700.
 *
 * You have a royalty-free right to use, modify, reproduce and distribute 
 * this example program (and/or any modified version) in any way you find useful,
 * provided you agree that Agilent Technologies has no warranty, obligations, or liability for any example programs.
 */

namespace WaveformRunSequence
{
    class Program
    {
        static void Main(string[] args)
        {
            SequenceModel seq = new SequenceModel();
            seq.Load("InfiniiVision_3000Series_WaveformDownload.iseq");
            seq.SetInstrumentAddresses("To Be Filled");
            Console.WriteLine("Acquiring waveform...");
            
            object[] ret = seq.Play("Channel1");
            byte[] waveformData = (byte[])(ret[0]);
            double xIncrement = (double)(ret[1]);
            double XOrigin = (double)(ret[2]);
            double YIncrement = (double)(ret[3]);
            double YOrigin = (double)(ret[4]);
            int YReference = (int)(ret[5]);

            Console.WriteLine();
            Console.WriteLine("(X Value, Y Value):");
            Console.WriteLine("===================");

            for (int i = 0; i < waveformData.Length; i++)
            {
                Console.WriteLine("(" + (XOrigin + (xIncrement * i)) + "," + ((waveformData[i] - YReference) * YIncrement + YOrigin) + ")");
            }

            Console.WriteLine();
            Console.WriteLine("Press enter to exit.");
            
            Console.ReadLine();

        }
    }
}
