﻿' 
' Acquires an autoscaled waveform from a selectable channel of an Agilent InfiniiVision 3000 Series oscilloscope.
'
' Description
' This program's IO code was generated by the export VB feature in Command Expert. For simplicity sake, this example 
' merely grabs the x and y axis waveform data.  It does not graph it.  
' 
' Instructions for Running:
' 1. Update the instrument address in the "To Be Filled" string statement.
' 2. Manually set the channel number, 1 thru 4, to match the incoming source.  
' 3. Add an appropriate input source to the 3000 series oscilloscope to the selected channel above.
' 4. Copy the InfiniiVision_3000Series_WaveformDownload.iseq into the program's run directory. Ex: Bin\Debug.
' 5. Run this program.
'
' Instructions for compiling.
' This example calls the SCPI.NET 3000 driver that is needed as a reference.  This file is downloaded when 
' Command Expert installs Agilent InfiniiVision 3000 Series command set.  See Command Expert's Visual Studio help for additional 
' information for the file location.  This location depends on your operating system.   
' 
' Viewing the Data
' This example lacks a graphing component for the sack of simplicity. The waveform data is returned in the BYTE format to 
' increase efficiency across the bus.  The conversion needed uses y-axis preamble information.  The x-axis uses a different
' set of preamble information. Please see the code below for the conversion information.  
'     
' Requirements:
' This example was written for oscilloscopes in the Agilent Agilent InfiniiVision 3000 Series. This was tested with firmware version 01.10.20111042700.
'
' You have a royalty-free right to use, modify, reproduce and distribute 
' this example program (and/or any modified version) in any way you find useful,
' provided you agree that Agilent Technologies has no warranty, obligations, or liability for any example programs.
' 
Imports Agilent.CommandExpert.ScpiNet.AgInfiniiVision3000X_01_20

Module Module1

    Sub Main()

        'Change the channel number (1-4) to match your input source
        Dim channel As String = "CHANNEL1"
        Dim xincrement, xorigin, yincrement, yorigin As Double
        Dim yreference As Integer
        Dim waveformBYTEFormatData As Byte() = Nothing
        Dim waveformSize As Integer = 1000


        Dim infiniivision As AgInfiniiVision3000X = New AgInfiniiVision3000X("To Be Filled")
        Console.WriteLine("Please wait 10 seconds for the waveform to be captured.")

        infiniivision.Transport.DefaultTimeout.Set(10000)
        infiniivision.SCPI.RST.Command()
        infiniivision.SCPI.CLS.Command()
        infiniivision.SCPI.AUToscale.Command(DBNull.Value, DBNull.Value, DBNull.Value, DBNull.Value, DBNull.Value)
        infiniivision.SCPI.DIGitize.Command(DBNull.Value, DBNull.Value, DBNull.Value, DBNull.Value, DBNull.Value)
        'Send 1000 points to represent the waveform.
        infiniivision.SCPI.WAVeform.POINts.CommandPointsMode("NORMal")
        'This example uses retrives 1000 points to represent the waveform
        infiniivision.SCPI.WAVeform.POINts.CommandPoints(waveformSize)
        infiniivision.SCPI.WAVeform.SOURce.Command(channel)
        infiniivision.SCPI.WAVeform.FORMat.Command("BYTE")
        infiniivision.SCPI.WAVeform.DATA.QueryBYTE(waveformBYTEFormatData)
        'X-Axis preamble information is used create the time based x axis values.  
        infiniivision.SCPI.WAVeform.XINCrement.Query(xincrement)
        infiniivision.SCPI.WAVeform.XORigin.Query(xorigin)
        'Y-axis preamble information converts the BYTE format to actual voltage values.  
        infiniivision.SCPI.WAVeform.YINCrement.Query(yincrement)
        infiniivision.SCPI.WAVeform.YORigin.Query(yorigin)
        infiniivision.SCPI.WAVeform.YREFerence.Query(yreference)

        'Generate Y-Axis Voltage Array from waveformBYTEFormatData
        Dim yAxisVoltage(waveformSize) As Double
        For i = 0 To (waveformBYTEFormatData.Length - 1)
            yAxisVoltage(i) = (waveformBYTEFormatData(i) - yreference) * yincrement + yorigin
        Next i


        'Generate X-Axis Time(s) Array from preamble information 
        Dim xAxisTime(waveformSize) As Double
        xAxisTime(0) = xorigin
        For i = 1 To (waveformBYTEFormatData.Length - 1)
            xAxisTime(i) = xAxisTime(i - 1) + xincrement
        Next

        'Hang Console

        Console.WriteLine(vbNewLine + "Application has created two arrays to plot" + vbNewLine +
                          "the waveform if a graphing package was availible." + vbNewLine +
                          "For example: plot(xAxisTime,yAxisVoltage)" + vbNewLine + "---Press any key to exit.---")
        Console.ReadLine()
    End Sub

End Module
